@@ -8,6 +8,7 @@ import math
 from pathlib import Path, PurePath
 import json
 from typing import List, Tuple, Dict, Union, Callable, Optional, Any
+from warnings import warn
 
 import numpy as np
 from tqdm import tqdm
@@ -188,7 +189,7 @@ class MIDITokenizer(ABC):
             print('\033[93mmiditok warning: tokens_to_events method no longer need multi_voc argument as '
                   'it is now a class attribute, it will be removed in future updates.\033[0m')
         events = []
-        if isinstance(self.vocab, list):  # multiple vocabularies
+        if self.is_multi_voc:  # multiple vocabularies
             for multi_token in tokens:
                 multi_event = []
                 for i, token in enumerate(multi_token):
@@ -400,9 +401,9 @@ class MIDITokenizer(ABC):
     def _token_duration_to_ticks(token_duration: str, time_division: int) -> int:
         r"""Converts a duration token value of the form x.x.x, for beat.position.resolution,
         in ticks.
-        Is also used for Time-Shifts.
+        Is also used for TimeShift tokens.
 
-        :param token_duration: Duration / Time-Shift token value
+        :param token_duration: Duration / TimeShift token value
         :param time_division: time division
         :return: the duration / time-shift in ticks
         """
@@ -515,8 +516,8 @@ class MIDITokenizer(ABC):
         out_dir.mkdir(parents=True, exist_ok=True)
         self.save_params(out_dir / 'config.txt')  # Saves the parameters with which the MIDIs are converted
 
-        for midi_path in tqdm(midi_paths, desc='Converting MIDIs to tokens') if logging else enumerate(midi_paths):
-            # Some MIDIs can contains errors that are raised by Mido, if so the loop continues
+        for midi_path in tqdm(midi_paths, desc=f'Tokenizing MIDIs ({out_dir.name})') if logging else midi_paths:
+            # Some MIDIs can contain errors that are raised by Mido, if so the loop continues
             try:
                 midi = MidiFile(PurePath(midi_path))
             except FileNotFoundError:
@@ -647,18 +648,29 @@ class MIDITokenizer(ABC):
         if '_mask' not in params:  # miditok < v1.2.0
             self._mask = False
 
+    @property
+    def is_multi_voc(self) -> bool: return isinstance(self.vocab, list)
+
     def __call__(self, midi: MidiFile, *args, **kwargs):
         return self.midi_to_tokens(midi, *args, **kwargs)
 
-    def __len__(self):
-        return [len(v) for v in self.vocab] if isinstance(self.vocab, list) else len(self.vocab)
+    def __len__(self) -> int:
+        if self.is_multi_voc:
+            warn('You are using a multi vocab tokenizer, returning the sum of the lengths of all vocabs.'
+                 'If you want the len per vocab, use the tokenizer.len property.')
+            return sum([len(v) for v in self.vocab])
+        return len(self.vocab)
+
+    @property
+    def len(self) -> Union[int, List[int]]:
+        return [len(v) for v in self.vocab] if self.is_multi_voc else len(self.vocab)
 
     def __getitem__(self, item: Union[int, str, Tuple[int, int]]) -> Union[str, int]:
         if isinstance(item, str):
             return self.vocab.event_to_token[item]
         elif isinstance(item, int):
             return self.vocab.token_to_event[item]
-        elif isinstance(item, tuple) and isinstance(self.vocab, list):
+        elif isinstance(item, tuple) and self.is_multi_voc:
             return self.vocab[item[0]].token_to_event[item[1]]
         else:
             raise IndexError('The index must be an integer or a string')
